==> haskell-genvalidity-property-1.0.0.0-93-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-genvalidity-property.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 genvalidity-property
version:              1.0.0.0
visibility:           public
id:                   genvalidity-property-1.0.0.0-HJ7ybGkITMq5pu5lASoKwd
key:                  genvalidity-property-1.0.0.0-HJ7ybGkITMq5pu5lASoKwd
license:              MIT
copyright:            Copyright: (c) 2016-2021 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Standard properties for functions on `Validity` types
category:             Testing
abi:                  4e04ebc52f5b7af3ea6f4ff60d4c50af
exposed:              True
exposed-modules:
    Test.Validity.Functions Test.Validity.Functions.CanFail
    Test.Validity.Functions.Equivalence
    Test.Validity.Functions.Idempotence Test.Validity.Functions.Inverse
    Test.Validity.Functions.Validity Test.Validity.GenValidity.Property
    Test.Validity.Operations Test.Validity.Operations.Associativity
    Test.Validity.Operations.Commutativity
    Test.Validity.Operations.Identity Test.Validity.Property
    Test.Validity.Property.Utils Test.Validity.Relations
    Test.Validity.Relations.Antireflexivity
    Test.Validity.Relations.Antisymmetry
    Test.Validity.Relations.Reflexivity
    Test.Validity.Relations.Symmetry
    Test.Validity.Relations.Transitivity
    Test.Validity.Shrinking.Property Test.Validity.Types

hidden-modules:       Paths_genvalidity_property
import-dirs:          /usr/lib/ghc-9.2.8/site-local/genvalidity-property-1.0.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/genvalidity-property-1.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-genvalidity-property
hs-libraries:         HSgenvalidity-property-1.0.0.0-HJ7ybGkITMq5pu5lASoKwd
depends:
    QuickCheck-2.14.3-AB831W8sF74KL3cz7DxP1X base-4.16.4.0
    genvalidity-1.1.0.0-KBSm8zqLtleKRPnpRQIZMH
    hspec-2.10.9-KuS4B4SgPwm179O4lsuAOc
    pretty-show-1.10-JwphvxEdk99BsHrT870tUy
    validity-0.12.0.2-8mLDnzAf1JNLFCf9Kp2tpt

haddock-interfaces:
    /usr/share/doc/haskell-genvalidity-property/html/genvalidity-property.haddock

haddock-html:         /usr/share/doc/haskell-genvalidity-property/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-genvalidity-property-1.0.0.0-123.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-genvalidity-property.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 genvalidity-property
version:              1.0.0.0
visibility:           public
id:                   genvalidity-property-1.0.0.0-57buIT55nlp7qysNFhFzvn
key:                  genvalidity-property-1.0.0.0-57buIT55nlp7qysNFhFzvn
license:              MIT
copyright:            Copyright: (c) 2016-2021 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Standard properties for functions on `Validity` types
category:             Testing
abi:                  60de611c73d8ad416430b7010875d896
exposed:              True
exposed-modules:
    Test.Validity.Functions Test.Validity.Functions.CanFail
    Test.Validity.Functions.Equivalence
    Test.Validity.Functions.Idempotence Test.Validity.Functions.Inverse
    Test.Validity.Functions.Validity Test.Validity.GenValidity.Property
    Test.Validity.Operations Test.Validity.Operations.Associativity
    Test.Validity.Operations.Commutativity
    Test.Validity.Operations.Identity Test.Validity.Property
    Test.Validity.Property.Utils Test.Validity.Relations
    Test.Validity.Relations.Antireflexivity
    Test.Validity.Relations.Antisymmetry
    Test.Validity.Relations.Reflexivity
    Test.Validity.Relations.Symmetry
    Test.Validity.Relations.Transitivity
    Test.Validity.Shrinking.Property Test.Validity.Types

hidden-modules:       Paths_genvalidity_property
import-dirs:          /usr/lib/ghc-9.4.8/site-local/genvalidity-property-1.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/genvalidity-property-1.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/genvalidity-property-1.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-genvalidity-property
hs-libraries:         HSgenvalidity-property-1.0.0.0-57buIT55nlp7qysNFhFzvn
depends:
    QuickCheck-2.14.3-Gpw9UoHUxB71c0Trj8n39O base-4.17.2.1
    genvalidity-1.1.1.0-JlHFxqNtJUTEO4hRrJMCRP
    hspec-2.10.9-8PqvxiZVgrL4DvXVyNhtnS
    pretty-show-1.10-Il8DKxKkDEW3pjtvdJ1ynD
    validity-0.12.1.0-FIzFF3lSpT53uOKNr6m0c7

haddock-interfaces:
    /usr/share/doc/haskell-genvalidity-property/html/genvalidity-property.haddock

haddock-html:         /usr/share/doc/haskell-genvalidity-property/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
